@@ -18,9 +18,9 @@ class Config:
     default_flags: List[str] = field(default_factory=lambda: ["short-report"])
     default_flags_tui: List[str] = field(default_factory=lambda: ["short-report"])
     shortcuts: Dict[str, List[str]] = field(default_factory=dict)
-    format_command: Optional[str] = None
+    format_command: str = ""
     storage_dir: Optional[Path] = None
-    skip_snapshot_updates_for_now: bool = False
+    show_updates: bool = False
 
 
 config = Config()
@@ -53,9 +53,7 @@ def read_config(path: Path, config=Config()) -> Config:
         pass
 
     try:
-        config.skip_snapshot_updates_for_now = tool_config[
-            "skip-snapshot-updates-for-now"
-        ]
+        config.show_updates = tool_config["show-updates"]
     except KeyError:
         pass
 
@@ -70,6 +68,6 @@ def read_config(path: Path, config=Config()) -> Config:
             storage_dir = path.parent.joinpath(storage_dir).absolute()
         config.storage_dir = storage_dir
 
-    config.format_command = tool_config.get("format-command", None)
+    config.format_command = tool_config.get("format-command", "")
 
     return config
