@@ -1,6 +1,5 @@
 from __future__ import annotations
 
-import contextlib
 import logging
 import pathlib
 import sys
@@ -16,7 +15,6 @@ from asttokens import LineNumbers
 from ._format import enforce_formatting
 from ._format import format_code
 
-
 if sys.version_info >= (3, 10):
     from itertools import pairwise
 else:
@@ -200,19 +198,11 @@ class SourceFile:
 
 
 class ChangeRecorder:
-    current: ChangeRecorder
 
     def __init__(self):
         self._source_files = defaultdict(SourceFile)
         self._changes = []
 
-    @contextlib.contextmanager
-    def activate(self):
-        old_recorder = ChangeRecorder.current
-        ChangeRecorder.current = self
-        yield self
-        ChangeRecorder.current = old_recorder
-
     def get_source(self, filename) -> SourceFile:
         filename = pathlib.Path(filename)
         if filename not in self._source_files:
@@ -220,9 +210,6 @@ class ChangeRecorder:
 
         return self._source_files[filename]
 
-    def change_set(self):
-        return Change(self)
-
     def files(self) -> Iterable[SourceFile]:
         return self._source_files.values()
 
@@ -248,7 +235,3 @@ class ChangeRecorder:
             print("file:", file.filename)
             for change in file.replacements:
                 print("  change:", change)
-
-
-global_recorder = ChangeRecorder()
-ChangeRecorder.current = global_recorder
