@@ -37,8 +37,8 @@ if sys.version_info >= (3, 13):
     # fixes #186
     try:
         import readline  # noqa
-    except ModuleNotFoundError:  # pragma: no cover
-        # should fix #189
+    except (ImportError, ModuleNotFoundError):  # pragma: no cover
+        # should fix #189 and #245
         pass
 
 
@@ -132,7 +132,9 @@ def pytest_configure(config):
     _config.read_config(pyproject, _config.config)
 
     console = Console()
-    if console.is_terminal:
+    if is_ci_run():
+        default_flags = {"disable"}
+    elif console.is_terminal:
         default_flags = _config.config.default_flags_tui
     else:
         default_flags = _config.config.default_flags
@@ -163,7 +165,7 @@ def pytest_configure(config):
             f"--inline-snapshot=disable can not be combined with other flags ({', '.join(flags-{'disable'})})"
         )
 
-    if xdist_running(config) or not is_implementation_supported() or is_ci_run():
+    if xdist_running(config) or not is_implementation_supported():
         state().active = False
 
     elif flags & {"review"}:
@@ -222,19 +224,22 @@ def snapshot_check(request):
     missing_values = state().missing_values
     incorrect_values = state().incorrect_values
 
+    extra = "\nIf you just created this value with --snapshot=create, the value is now created and you can ignore this message."
+
     if missing_values != 0:
         pytest.fail(
             (
                 "your snapshot is missing one value."
                 if missing_values == 1
                 else f"your snapshot is missing {missing_values} values."
-            ),
+            )
+            + extra,
             pytrace=False,
         )
 
     if incorrect_values != 0:
         pytest.fail(
-            "some snapshots in this test have incorrect values.",
+            "some snapshots in this test have incorrect values." + extra,
             pytrace=False,
         )
 
@@ -292,9 +297,7 @@ def call_once(f):
 
 
 def link(text, link=None):
-    if link is None:
-        link = text
-    return f"[italic blue link={link}]{text}[/]"
+    return f"[italic blue link={link or text}]{text}[/]"
 
 
 def category_link(category):
@@ -317,25 +320,27 @@ def pytest_sessionfinish(session, exitstatus):
 
             return con
 
+        disable_info = "This means that tests with snapshots will continue to run, but snapshot(x) will only return x and inline-snapshot will not be able to fix snapshots or generate reports."
+
         if xdist_running(config):
             if state().flags != {"disable"}:
                 console().print(
-                    "INFO: inline-snapshot was disabled because you used xdist\n"
+                    f"INFO: inline-snapshot was disabled because you used xdist. {disable_info}\n"
                 )
             return
 
         if env_var := is_ci_run():
-            if state().flags != {"disable"}:
+            if state().flags == {"disable"}:
                 console().print(
-                    f'INFO: CI run was detected because environment variable "{env_var}" was defined.\n'
-                    + "INFO: inline-snapshot runs with --inline-snapshot=disabled by default in CI.\n"
+                    f'INFO: CI run was detected because environment variable "{env_var}" was defined. '
+                    f"inline-snapshot runs with --inline-snapshot=disable by default in CI. {disable_info} You can change this by using --inline-snasphot=report for example.\n"
                 )
-            return
+                return
 
         if not is_implementation_supported():
             if state().flags != {"disable"}:
                 console().print(
-                    f"INFO: inline-snapshot was disabled because {sys.implementation.name} is not supported\n"
+                    f"INFO: inline-snapshot was disabled because {sys.implementation.name} is not supported. {disable_info}\n"
                 )
             return
 
@@ -450,19 +455,9 @@ def pytest_sessionfinish(session, exitstatus):
 
                 if (
                     flag == "update"
-                    and _config.config.skip_snapshot_updates_for_now
+                    and not _config.config.show_updates
                     and not "update" in state().flags
                 ):
-                    console().print(
-                        f"{len(changes[flag])} updates are hidden. "
-                        f"Please report why you do not want these updates so that inline-snapshot can create better snapshots in the future."
-                    )
-                    console().print("You can find more information about updates here:")
-                    console().print(
-                        link(
-                            "https://15r10nk.github.io/inline-snapshot/latest/categories/#update"
-                        )
-                    )
                     continue
 
                 cr = ChangeRecorder()
